#!/usr/bin/python

# <bitbar.title>Fuzzy Clock</bitbar.title>
# <bitbar.author>Dylan Evans</bitbar.author>
# <bitbar.author.github>whonut</bitbar.author.github>
# <bitbar.desc>Display the current system time in a 'fuzzy' manner, rounding to the nearest 5 minutes and using words.</bitbar.desc>
# <bitbar.version>1.0</bitbar.version>
#
# 1 second refresh rate may be overkill. Wording & formatting of the time may
# also be easily altered below.

from __future__ import absolute_import, division, print_function, unicode_literals
from time import localtime
from datetime import datetime

def round_to_nearest_five(n):
    '''Round the float n to the nearest 5.'''
    return int(5 * round(n / 5))


def next_hour(hour):
    # modulo before adding one so that 11 => 12 and not 0
    return (hour % 12) + 1


def fuzzy_time(struct_time):
    '''Return the current 'fuzzy time' (rounded to the nearest 5 minutes) as a
       string.'''

    # Split it into hours & minutes and rounding the minutes to make the time
    # 'fuzzy'. Use 12-hour clock.
    hour = (struct_time.tm_hour % 12) or 12
    minute = struct_time.tm_min + (struct_time.tm_sec / 60)
    rounded_min = round_to_nearest_five(minute)
    if rounded_min == 60:
        rounded_min = 0
        hour = next_hour(hour)

    num_word = {1: "ONE", 2: "TWO", 3: "THREE", 4: "FOUR", 5: "FIVE", 6: "SIX",
                7: "SEVEN", 8: "EIGHT", 9: "NINE", 10: "TEN", 11: "ELEVEN",
                12: "TWELVE", 20: "TWENTY", 25: "TWENTY-FIVE"}

    # Work out what to display and display it.
    if rounded_min == 0:
        return "{hr} O'CLOCK".format(hr=num_word[hour])
    elif rounded_min == 15:
        return "QUARTER PAST {hr}".format(hr=num_word[hour])
    elif rounded_min < 30:
        return "{min} PAST {hr}".format(min=num_word[rounded_min],
                                        hr=num_word[hour])
    elif rounded_min == 30:
        return "HALF PAST {hr}".format(hr=num_word[hour])
    elif rounded_min == 45:
        return "QUARTER TO {hr}".format(hr=num_word[next_hour(hour)])
    elif rounded_min == 55:
        return "NEARLY {hr}".format(hr=num_word[next_hour(hour)])
    else:
        return "{min} TO {hr}".format(min=num_word[60-rounded_min],
                                      hr=num_word[next_hour(hour)])

def current_time(struct_time):
    hour = (struct_time.tm_hour % 12) or 12
    minute = struct_time.tm_min + (struct_time.tm_sec / 60)

    mon_word = {1: "January", 2: "February", 3: "March", 4: "April", 5: "May", 6: "June",
                7: "July", 8: "August", 9: "September", 10: "October", 11: "November",
                12: "December"}

    return ("{MM} {dd:02d}, {yyyy} {hr:02d}:{mt:02d}".format(dd=struct_time.tm_mday,
        MM=mon_word[struct_time.tm_mon],
        yyyy=struct_time.tm_year,
        hr=struct_time.tm_hour,
       mt=struct_time.tm_min))

retire = datetime(2044, 10,28, 12, 0, 0)
birth = datetime(1989, 10,28, 12, 0, 0)

def count_alive(birth, retire):
    result = ''
    diff = retire - datetime.now()

    total = retire - birth
    elapsed_diff = datetime.now() - birth
    totalF = format(int(total.total_seconds()/60),' ,d')
    remain = format(int(elapsed_diff.total_seconds()/60),' ,d')
    percent = format(((elapsed_diff.total_seconds()/60)/(total.total_seconds()/60))*100,'.2f')

    result += '~ {0}% elapsed'.format(percent)

    # remainM = format(int(diff.total_seconds()/60),' ,d')
    # result += '\n~{0} minutes left'.format(remainM)

    # remainH = format(int(diff.total_seconds()/(3600)),' ,d')
    # result += '\n~{0} hours left'.format(remainH)

    remainD = format(int(diff.total_seconds()/(3600*24)),' ,d')
    result += '\n~{0} days left'.format(remainD)

    remainW = format(int(diff.total_seconds()/(3600*24*7)),' ,d')
    result += '\n~{0} weeks left'.format(remainW)

    remainMonth = format(int(diff.total_seconds()/(3600*24*(365/12))),' ,d')
    result += '\n~{0} months left'.format(remainMonth)

    remain = format(int(diff.total_seconds()/(3600*24*(365))),' ,d')
    result += '\n~{0} years left'.format(remain)

    return result


# DINAlternate-Bold 15
# HiraMaruPro 14

if __name__ == '__main__':
    print(fuzzy_time(localtime()) + " | font='DINAlternate-Bold' size=14")
    print("---")
    print(current_time(localtime()))
    print("---")
    print(count_alive(birth, retire))
